
TODO: TODO_95_88_52_44: list server and client supported commands

There should be a way to know:
*   what commands are supported by client (current shell)
*   what commands are supported by server (it could be many servers due to FS_57_36_37_48 clients coexistence)

Status:
*   Script `@/exe/check_env.bash` already lists those from client-side.
*   `check_env` can also retrieve list of `zero_index_arg` via FS_15_79_76_85 line processor plugin-s

See also:
*   FS_42_76_93_51 very first zero arg mapping interp
*   FS_15_79_76_85 line processor
